package fr.dgedl.demo.persistence.dao.impl;

import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import fr.dgedl.demo.persistence.dao.GenericDao;

public abstract class GenericDaoImpl<T extends Object> implements GenericDao<T> {

	private static final Log log = LogFactory.getFactory().getInstance(GenericDaoImpl.class);

	@PersistenceContext
	protected EntityManager em;

	@Override
	public T save(T pojo) {
		log.debug("merge instance " + pojo.getClass().getName());
		return em.merge(pojo);
	}

	@Override
	public void remove(Class<T> classe, int id) {
		log.debug("removing instance " + classe.getName() + " with id: " + id);
		T pojo = findById(classe, id);
		if (pojo != null) {
			em.remove(pojo);
		}
	}

	@Override
	public void delete(T pojo) {
		log.debug("removing instance " + pojo.getClass().getName());
		em.remove(pojo);
	}

	@Override
	public T findById(Class<T> classe, int id) {
		log.debug("findById instance " + classe.getName() + " with id: " + id);
		return (T) em.find(classe, id);
	}
	
	@Override
	@SuppressWarnings("unchecked")
	public List<T> findAll(Class<T> classe) {
		StringBuffer jpql = new StringBuffer(20);
		jpql.append("from ").append(classe.getName());
		List<T> result = em.createQuery(jpql.toString()).getResultList();
		log.debug("finding all successful, result size : " + result.size());
		return result;
	}

	@Override
	@SuppressWarnings("unchecked")
	public List<T> findByQuery(String jpql) {
		List<T> result = em.createQuery(jpql).getResultList();
		log.debug("finding by query successful, result size : " + result.size());
		return result;
	}

}