package fr.dgedl.demo.service.impl;

import java.util.List;

import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang.RandomStringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import fr.dgedl.demo.persistence.dao.UserAccountDao;
import fr.dgedl.demo.persistence.entity.UserAccount;
import fr.dgedl.demo.service.UserService;

@Service @Transactional
public class UserServiceImpl implements UserService {
	
	private static final Log LOG = LogFactory.getFactory().getInstance(UserServiceImpl.class);
	
	@Autowired
	private UserAccountDao userAccountDao;
	
	@Override
	public UserAccount getAccountWithId(Integer id) {
		return userAccountDao.findById(UserAccount.class, id);
	}
	
	@Override
	public UserAccount login(String email, String password) {
		// on rcupre le compte utilisateur
		return userAccountDao.findAccount(email, DigestUtils.sha256Hex(password));
	}
	
	@Override
	public UserAccount register(String email, String password) {
		// on cre le nouveau compte utilisateur
		UserAccount account = new UserAccount();
		account.setEmail(email);
		account.setPassword(DigestUtils.sha256Hex(password));
		account.setSecurity(RandomStringUtils.randomAlphanumeric(50));
		
		try {
			account = userAccountDao.save(account);
		} catch (Exception e) {
			LOG.error("Un problme est survenu lors de l'enregistrement de l'utilisateur ayant l'email " + email);
		}
		return account;
	}
	
	@Override
	public List<UserAccount> getAllAccounts() {
		return userAccountDao.findAll(UserAccount.class);
	}

}