package fr.dgedl.demo.jndi;

import java.util.ResourceBundle;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.naming.Reference;
import javax.naming.StringRefAddr;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public final class ContextDatasourceCreator {

	private static final Log LOG = LogFactory.getFactory().getInstance(ContextDatasourceCreator.class);

	private static ResourceBundle datasourceBundle = ResourceBundle.getBundle("datasource");

	private ContextDatasourceCreator() {
		//
	}

	public static void init() {
		try {
			// initialisation du contexte
			System.setProperty(Context.INITIAL_CONTEXT_FACTORY, "com.sun.jndi.fscontext.RefFSContextFactory");
			System.setProperty(Context.PROVIDER_URL, "file:" + System.getProperty("java.io.tmpdir"));
			InitialContext context = new InitialContext();
			
			// cration d'une rfrence sur la DataSource (website)
			Reference reference = new Reference("javax.sql.DataSource", "org.apache.commons.dbcp.BasicDataSourceFactory", null);
			reference.add(new StringRefAddr("driverClassName", "com.mysql.jdbc.Driver"));
			reference.add(new StringRefAddr("url", datasourceBundle.getString("website.database.url")));
			reference.add(new StringRefAddr("username", datasourceBundle.getString("website.user.name")));
			reference.add(new StringRefAddr("password", datasourceBundle.getString("website.user.password")));
			// liaison de la DataSource au contexte
			context.rebind("java:comp/env/jdbc/" + datasourceBundle.getString("website.jndi.name"), reference);
			
			LOG.info("contexte JNDI ajout pour la datasource : " + datasourceBundle.getString("website.database.url"));
		} catch (NamingException ex) {
			LOG.error(ex.getMessage());
		}
	}
	
}